%define abiversion 19
%bcond_with charls2

Name:           dcmtk
Version:        3.6.9
Release:        2
Summary:        Offis DICOM Toolkit (DCMTK)
License:        Apache-2.0 AND BSD-3-Clause
URL:            https://dicom.offis.de/dcmtk.php.en
Source0:        https://dicom.offis.de/download/dcmtk/dcmtk369/%{name}-%{version}.tar.gz
# PATCH-FIX-OPENSUSE dcmtk-fix-DCMTKTargets.cmake.patch -- Do not track executables to be able to use dcmtk-devel without dcmtk package

%if %{with charls2}
Patch0:      0001-Use-system-CharLS-include.patch
Patch1:      0002-Add-FindCharLS.patch
Patch2:      0003-Find-and-include-CharLS.patch
Patch3:      0004-Use-cmake-suggested-locations-for-CharLS.patch
Patch4:      0005-Correct-CharLS-API-call.patch
Patch5:      0006-Remove-reference-to-bundled-CharLS.patch
Patch6:      0007-Update-JLS_ERROR-to-jpegls_error-in-CharLS-usage.patch
Patch7:      0008-Correct-JpegLsReadHeader-arguments.patch
Patch8:      0009-Update-JlsParameters-for-new-CharLS.patch
Patch9:      0010-Correct-JpegLsDecode-arguments-for-CharLS-2.patch
Patch10:      0011-Update-ilv-for-new-CharLS.patch
Patch11:      0012-Correct-extra-include-for-CharLS.patch
Patch12:      0013-Update-errors-to-use-enum-class-in-CharLS-2.patch
Patch13:      0014-Define-BYTE-for-CharLS.patch
Patch14:      0015-Update-colorTransformation-for-CharLS-2.patch
Patch15:      0016-Update-JpegLsEncode-for-CharLS-2.patch
%endif
Patch16:         dcmtk-fix-DCMTKTargets.cmake.patch
# PATCH-FIX-UPSTREAM
Patch17:         0001-Added-check-to-make-sure-HighBit-BitsAllocated.patch
Patch18:         0001-Replaced-call-of-delete-by-delete.patch
Patch19:         0001-Fixed-issue-rendering-invalid-monochrome-image.patch
# CVE-2025-25472
Patch20:         0001-Fixed-another-issue-with-invalid-mono-images.patch
# CVE-2025-25474
Patch21:         0001-Fixed-another-issue-with-invalid-DICOM-images.patch
# CVE-2025-25475
Patch22:         0001-Fixed-issue-with-invalid-RLE-compressed-DICOM-images.patch
# CVE-2025-2357 
Patch23:         0001-Fixed-segfault-in-JPEG-LS-decoder.patch

BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc gcc-c++
BuildRequires:  kf5-filesystem
BuildRequires:  libtiff-devel
BuildRequires:  libjpeg-devel
BuildRequires:  libpng-devel
BuildRequires:  libxml2-devel
BuildRequires:  openssl-devel >= 1.0.1
BuildRequires:  zlib-devel
%if %{with charls2}
BuildRequires:  CharLS-devel >= 2.0.0
%endif


%description
DCMTK is a collection of libraries and applications implementing large
parts the DICOM standard. It includes software for examining,
constructing and converting DICOM image files, handling offline media,
sending and receiving images over a network connection, as well as
demonstrative image storage and worklist servers. DCMTK is is written
in a mixture of ANSI C and C++.  It comes in complete source code and 
is made available as "open source" software. This package includes
multiple fixes taken from the "patched DCMTK" project.

Install DCMTK if you are working with DICOM format medical image files.

%package devel
Summary:        Development Libraries and Headers for dcmtk
%if %{with charls2}
Requires:       CharLS-devel
%endif
Requires:       libpng-devel
Requires:       libtiff-devel

%description devel
This package provides development libraries and headers needed to build
software using dcmtk.

%prep
%autosetup -p1

%build
export CFLAGS="%{optflags} -fPIC -Wno-error=deprecated-declarations"
export CXXFLAGS="%{optflags} -fPIC -Wno-error=deprecated-declarations"
export LDFLAGS="%{__global_ldflags} -fPIC"
%cmake -DCMAKE_BUILD_TYPE:STRING="Release" \
 -DDCMTK_INSTALL_LIBDIR=%{_lib} \
 -DDCMTK_INSTALL_CMKDIR=%{_lib}/cmake/%{name} \
 -DCMAKE_INSTALL_DOCDIR:PATH=%{_pkgdocdir} \
 -DCMAKE_INSTALL_INCLUDEDIR:PATH=include \
 -DCMAKE_INSTALL_MANDIR:PATH=%{_mandir} \
 -DCMAKE_INSTALL_PREFIX:PATH=%{_prefix} \
 -DCMAKE_INSTALL_SYSCONFDIR:PATH=%{_sysconfdir} \
 -DCMAKE_INSTALL_DATADIR:PATH=share \
 -DBUILD_APPS:BOOL=ON \
 -DBUILD_SHARED_LIBS:BOOL=ON \
 -DBUILD_SINGLE_SHARED_LIBRARY:BOOL=OFF \
 -DDCMTK_WITH_OPENSSL:BOOL=ON \
 -DDCMTK_WITH_PNG:BOOL=ON \
 -DDCMTK_WITH_PRIVATE_TAGS:BOOL=ON \
 -DDCMTK_WITH_TIFF:BOOL=ON \
 -DDCMTK_WITH_XML:BOOL=ON \
 -DDCMTK_WITH_CHARLS:BOOL=ON \
 -DDCMTK_WITH_ZLIB:BOOL=ON \
 -DDCMTK_ENABLE_CXX11:BOOL=ON \
 -Wno-dev
%cmake_build

%install
%cmake_install

rm -f %{buildroot}%{_datadir}/%{name}/wlistdb/OFFIS/lockfile
# Move doc files from /usr/share/doc/dcmtk-<version> to /usr/share/doc/packages/dcmtk/
mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}%{_datadir}/doc/%{name}-%{version} %{buildroot}%{_docdir}/dcmtk

# Install README file to documentation
install -pm 0644 README %{buildroot}%{_docdir}/dcmtk/


%check
%ctest

%files
%license COPYRIGHT
%doc %{_docdir}/dcmtk/
%dir %{_sysconfdir}/dcmtk-%{version}
%config(noreplace) %{_sysconfdir}/dcmtk-%{version}/*.cfg
%{_bindir}/*
%{_libdir}/*.so.%{abiversion}
%{_libdir}/*.so.%{abiversion}.3.6*
%{_datadir}/dcmtk-%{version}/
%{_mandir}/man1/*

%files devel
%{_includedir}/dcmtk/
%{_libdir}/*.so
%{_libdir}/cmake/dcmtk/
%{_libdir}/pkgconfig/dcmtk.pc


%changelog
* Fri Apr 18 2025 Doris Chao <doriscchao@tencent.com> - 3.6.9-2
- [Type] security
- [DESC] Add 0001-Fixed-segfault-in-JPEG-LS-decoder.patch to fix CVE-2025-2357. 

* Mon Feb 24 2025 Doris Chao <doriscchao@tencent.com> - 3.6.9-1
- [Type] security
- [DESC] Update to 3.6.9 to fix CVE-2024-34509，CVE-2024-34508,CVE-2022-43272.
- And also add patches:
  * 0001-Fixed-another-issue-with-invalid-mono-images.patch
    (CVE-2025-25472)
  * 0001-Fixed-another-issue-with-invalid-DICOM-images.patch
    (CVE-2025-25474)
  * 0001-Fixed-issue-with-invalid-RLE-compressed-DICOM-images.patch
    (CVE-2025-25475)
  * 0001-Added-check-to-make-sure-HighBit-BitsAllocated.patch
    (CVE-2024-52333)
  * 0001-Replaced-call-of-delete-by-delete.patch
  * 0001-Fixed-issue-rendering-invalid-monochrome-image.patch
    (CVE-2024-47796)

* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.6.7-1
- initial build

